@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.11 2000/02/11 23:35:09 jleach Exp $ */
+/* $Id: weather.c,v 1.13 2000/02/19 02:10:26 spapadim Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -33,7 +33,7 @@
 
 static WeatherUnits weather_units = UNITS_IMPERIAL;
 static WeatherForecastType weather_forecast = FORECAST_STATE;
-static gboolean weather_radar = TRUE;
+static gboolean weather_radar = FALSE;
 
 static gchar *weather_proxy_url = NULL;
 static gchar *weather_proxy_user = NULL;
@@ -1078,12 +1078,19 @@ static void wx_get_start (WeatherInfo *info)
 
 gboolean _weather_info_fill (WeatherInfo *info, WeatherLocation *location, WeatherInfoFunc cb)
 {
+    g_return_val_if_fail(((info == NULL) && (location != NULL)) || \
+                         ((info != NULL) && (location == NULL)), FALSE);
+
+    /* FIX */
+    if (!requests_init(cb, info)) {
+        g_warning(_("Another update already in progress!\n"));
+        return FALSE;
+    }
+
     if (!info) {
-        g_return_val_if_fail(location != NULL, FALSE);
         info = g_new(WeatherInfo, 1);
         info->location = weather_location_clone(location);
     } else {
-        g_return_val_if_fail(location == NULL, FALSE);
         location = info->location;
         g_free(info->forecast);
         gdk_imlib_free_pixmap(info->radar);
@@ -1106,11 +1113,6 @@ gboolean _weather_info_fill (WeatherInfo *info, WeatherLocation *location, Weath
     info->forecast = NULL;
     info->radar = NULL;
 
-    if (!requests_init(cb, info)) {
-        g_warning(_("Another update already in progress!\n"));
-        return FALSE;
-    }
-
     metar_get_start(info);
  
     iwin_get_start(info);
@@ -1412,7 +1414,7 @@ gchar *weather_info_get_weather_summary (WeatherInfo *info)
     static gchar buf[200];
     g_return_val_if_fail(info != NULL, NULL);
     if (!info->valid)
-        return "----";
+        return _("Retrieval failed");
     strcpy(buf, weather_info_get_conditions(info));
     if (!strcmp(buf, "-"))
         strcpy(buf, weather_info_get_sky(info));
