@@ -5,10 +5,11 @@
 #include <gnome.h>
 #include <applet-widget.h>
 
-#include <linux-proc.h>
-#include <properties.h>
+#include <local-properties.h>
 #include <load-graph.h>
 
+#include <linux-proc.h>
+
 BEGIN_GNOME_DECLS
 
 /* start a new instance of the cpuload applet */
@@ -27,10 +28,18 @@ make_swapload_applet (const gchar *goad_id);
 GtkWidget *
 make_netload_applet (const gchar *goad_id);
 
-/* show properties dialog. */
+/* start a new instance of the loadavg applet */
+GtkWidget *
+make_loadavg_applet (const gchar *goad_id);
+
+/* show default properties dialog. */
 void
 multiload_properties_cb (AppletWidget *widget, gpointer data);
 
+/* show local properties dialog. */
+void
+multiload_local_properties_cb (AppletWidget *widget, gpointer data);
+
 /* run gtop */
 void 
 start_gtop_cb (AppletWidget *widget, gpointer data);
@@ -38,6 +47,9 @@ start_gtop_cb (AppletWidget *widget, gpointer data);
 /* Load graph properties descriptor. */
 extern GnomePropertyDescriptor LoadGraphProperty_Descriptor;
 
+/* Load graph local properties descriptor. */
+extern GnomePropertyDescriptor LoadGraphLocalProperty_Descriptor;
+
 END_GNOME_DECLS
 
 #endif
