@@ -39,6 +39,10 @@ static const gchar *net_texts [4] = {
     N_("SLIP"), N_("PPP"), N_("ETH"), N_("Other"),
 };
 
+static const gchar *loadavg_texts [2] = {
+    N_("Used"), N_("Free")
+};
+
 static const gchar *cpu_color_defs [4] = {
     "#ffffffff4fff", "#dfffdfffdfff",
     "#afffafffafff", "#000000000000"
@@ -58,6 +62,9 @@ static const gchar *net_color_defs [4] = {
     "#00008fff0000", "#ffffffff4fff"
 };
 
+static const gchar *loadavg_color_defs [2] = {
+    "#cfff5fff5fff", "#00008fff0000"
+};
 
 #define ADD_PROPERTIES(x,y) multiload_property_object_list = g_list_append (multiload_property_object_list, gnome_property_object_new (& ## x ## Property_Descriptor, &multiload_properties. ## y ##))
         
@@ -70,6 +77,8 @@ make_new_applet (const gchar *goad_id)
 	return make_swapload_applet (goad_id);
     else if (strstr (goad_id, "multiload_netload_applet"))
 	return make_netload_applet (goad_id);
+    else if (strstr (goad_id, "multiload_loadavg_applet"))
+	return make_loadavg_applet (goad_id);
     else
 	return make_cpuload_applet (goad_id);
 }
@@ -124,7 +133,6 @@ main (int argc, char **argv)
     multiload_properties.cpuload.color_defs = cpu_color_defs;
     multiload_properties.cpuload.adj_data [0] = 500;
     multiload_properties.cpuload.adj_data [1] = 40;
-    multiload_properties.cpuload.adj_data [2] = 40;
 
     multiload_properties.memload.n = 4;
     multiload_properties.memload.name = "memload";
@@ -138,7 +146,6 @@ main (int argc, char **argv)
     multiload_properties.memload.color_defs = mem_color_defs;
     multiload_properties.memload.adj_data [0] = 500;
     multiload_properties.memload.adj_data [1] = 40;
-    multiload_properties.memload.adj_data [2] = 40;
 
     multiload_properties.swapload.n = 2;
     multiload_properties.swapload.name = "swapload";
@@ -152,7 +159,6 @@ main (int argc, char **argv)
     multiload_properties.swapload.color_defs = swap_color_defs;
     multiload_properties.swapload.adj_data [0] = 500;
     multiload_properties.swapload.adj_data [1] = 40;
-    multiload_properties.swapload.adj_data [2] = 40;
 
     multiload_properties.netload.n = 4;
     multiload_properties.netload.name = "netload";
@@ -166,7 +172,21 @@ main (int argc, char **argv)
     multiload_properties.netload.color_defs = net_color_defs;
     multiload_properties.netload.adj_data [0] = 500;
     multiload_properties.netload.adj_data [1] = 40;
-    multiload_properties.netload.adj_data [2] = 40;
+
+    multiload_properties.loadavg.n = 2;
+    multiload_properties.loadavg.name = "loadavg";
+#ifdef ENABLE_NLS
+    {
+        int i;
+        for (i=0;i<2;i++) swap_texts[i]=_(swap_texts[i]);
+    }
+#endif
+    multiload_properties.loadavg.texts = loadavg_texts;
+    multiload_properties.loadavg.color_defs = loadavg_color_defs;
+    multiload_properties.loadavg.adj_data [0] = 500;
+    multiload_properties.loadavg.adj_data [1] = 40;
+    multiload_properties.loadavg.adj_data [2] = 10;
+
 
     /* Add property objects. */
 
@@ -174,6 +194,7 @@ main (int argc, char **argv)
     ADD_PROPERTIES (LoadGraph, memload);
     ADD_PROPERTIES (LoadGraph, swapload);
     ADD_PROPERTIES (LoadGraph, netload);
+    ADD_PROPERTIES (LoadGraph, loadavg);
 
     /* This looks really ugly, but libgnomeui is already freezed so I can't
      * add new function there ... */
@@ -194,6 +215,10 @@ main (int argc, char **argv)
     ((GnomePropertyObject *) c->data)->label = gtk_label_new (_("Net Load"));
     gtk_widget_ref (((GnomePropertyObject *) c->data)->label);
 
+    c = g_list_nth (multiload_property_object_list, 4);
+    ((GnomePropertyObject *) c->data)->label = gtk_label_new (_("Load Average"));
+    gtk_widget_ref (((GnomePropertyObject *) c->data)->label);
+
     /* Read properties. */
     multiload_init_properties ();
 
