@@ -23,22 +23,12 @@
 
 #include "global.h"
 
-static gint
-applet_save_session (GtkWidget *widget, char *privcfgpath,
-		     char *globcfgpath, gpointer data)
-{
-	return FALSE;
-	widget = NULL;
-	privcfgpath = NULL;
-	globcfgpath = NULL;
-	data = NULL;
-}
-
 /* start a new instance of the memload applet */
 GtkWidget *
 make_memload_applet (const gchar *goad_id)
 {
     GtkWidget *applet;
+    LoadGraphProperties *prop_data;
     LoadGraph *g;
 
     /* create a new applet_widget */
@@ -48,12 +38,15 @@ make_memload_applet (const gchar *goad_id)
     if (!applet)
 	g_error ("Can't create applet!\n");
 
-    g = load_graph_new (4, N_("Memory Load"), &multiload_properties.memload,
-			multiload_properties.memload.adj_data[0],
-			multiload_properties.memload.adj_data[1],
-			multiload_properties.memload.adj_data[2], GetMemory);
+    prop_data = g_memdup (&multiload_properties.memload,
+			  sizeof (LoadGraphProperties));
 
-    applet_widget_add (APPLET_WIDGET(applet), g->frame);
+    g = load_graph_new (APPLET_WIDGET (applet), 4, N_("Memory Load"),
+			&multiload_properties.memload, prop_data,
+			multiload_properties.memload.adj_data[0],
+			multiload_properties.memload.adj_data[1], GetMemory);
+
+    applet_widget_add (APPLET_WIDGET(applet), g->main_widget);
     gtk_widget_show (applet);
 
     load_graph_start (g);
@@ -61,10 +54,17 @@ make_memload_applet (const gchar *goad_id)
     applet_widget_register_stock_callback (APPLET_WIDGET(applet),
 					   "properties",
 					   GNOME_STOCK_MENU_PROP,
-					   _("Properties..."),
+					   _("Default Properties..."),
 					   multiload_properties_cb,
 					   g);
 
+    applet_widget_register_stock_callback (APPLET_WIDGET(applet),
+					   "local_properties",
+					   GNOME_STOCK_MENU_PROP,
+					   _("Properties..."),
+					   multiload_local_properties_cb,
+					   g);
+
     applet_widget_register_stock_callback (APPLET_WIDGET(applet),
 					   "run_gtop",
 					   GNOME_STOCK_MENU_INDEX,
