@@ -22,22 +22,12 @@
 
 #include "global.h"
 
-static gint
-applet_save_session (GtkWidget *widget, char *privcfgpath,
-		     char *globcfgpath, gpointer data)
-{
-	return FALSE;
-        widget = NULL;
-        privcfgpath = NULL;
-        globcfgpath = NULL;
-        data = NULL;
-}
-
 /* start a new instance of the netload applet */
 GtkWidget *
 make_netload_applet (const gchar *goad_id)
 {
     GtkWidget *applet;
+    LoadGraphProperties *prop_data;
     LoadGraph *g;
 
     /* create a new applet_widget */
@@ -47,12 +37,15 @@ make_netload_applet (const gchar *goad_id)
     if (!applet)
 	g_error ("Can't create applet!\n");
 
-    g = load_graph_new (4, N_("Net Load"), &multiload_properties.netload,
-			multiload_properties.netload.adj_data[0],
-			multiload_properties.netload.adj_data[1],
-			multiload_properties.netload.adj_data[2], GetNet);
+    prop_data = g_memdup (&multiload_properties.netload,
+			  sizeof (LoadGraphProperties));
 
-    applet_widget_add (APPLET_WIDGET(applet), g->frame);
+    g = load_graph_new (APPLET_WIDGET (applet), 4, N_("Net Load"),
+			&multiload_properties.netload, prop_data,
+			multiload_properties.netload.adj_data[0],
+			multiload_properties.netload.adj_data[1], GetNet);
+
+    applet_widget_add (APPLET_WIDGET(applet), g->main_widget);
     gtk_widget_show (applet);
 
     load_graph_start (g);
@@ -60,10 +53,23 @@ make_netload_applet (const gchar *goad_id)
     applet_widget_register_stock_callback (APPLET_WIDGET(applet),
 					   "properties",
 					   GNOME_STOCK_MENU_PROP,
-					   _("Properties..."),
+					   _("Default Properties..."),
 					   multiload_properties_cb,
 					   g);
 
+    applet_widget_register_stock_callback (APPLET_WIDGET(applet),
+					   "local_properties",
+					   GNOME_STOCK_MENU_PROP,
+					   _("Properties..."),
+					   multiload_local_properties_cb,
+					   g);
+
+    applet_widget_register_stock_callback (APPLET_WIDGET(applet),
+					   "run_gtop",
+					   GNOME_STOCK_MENU_INDEX,
+					   _("Run gtop..."),
+					   start_gtop_cb, NULL);
+    
     applet_widget_set_tooltip(APPLET_WIDGET(applet), "Network Load");
     
     return applet;
