@@ -42,6 +42,9 @@ static void about_cb (AppletWidget *widget, gpointer data)
 			"Released under the GNU general public license."),
 			NULL);
 	gtk_widget_show (about);
+	return;
+	widget = NULL;
+	data = NULL;
 }
 
 static void esd_control_cb (AppletWidget *widget, gpointer data)
@@ -60,12 +63,16 @@ static void esd_control_cb (AppletWidget *widget, gpointer data)
 		{
 		esd_sound_control(ESD_CONTROL_STANDBY, ad);
 		}
+	return;
+	widget = NULL;
 }
 
 static void manager_cb (AppletWidget *widget, gpointer data)
 {
 	AppData *ad = data;
 	manager_window_show(ad);
+	return;
+	widget = NULL;
 }
 
 static void sync_esd_menu_item(AppData *ad)
@@ -245,6 +252,8 @@ static void applet_change_back(GtkWidget *applet, PanelBackType type, char *pixm
 				}
 			break;
 		}
+	return;
+	applet = NULL;
 }
 
 /* clean up function to free all the applet's memory and stop io,timers */
@@ -263,6 +272,8 @@ static void destroy_applet(GtkWidget *widget, gpointer data)
 	g_free(ad->esd_host);
 	g_free(ad->theme_file);
 	g_free(ad);
+	return;
+	widget = NULL;
 }
 
 static AppData *create_new_app(GtkWidget *applet)
@@ -384,6 +395,8 @@ static void applet_change_orient(GtkWidget *w, PanelOrientType o, gpointer data)
 	if (!ad->skin) return; /* we are done if in startup */
 
 	reload_theme(ad);
+	return;
+	w = NULL;
 }
 
 #ifdef HAVE_PANEL_PIXEL_SIZE
@@ -403,6 +416,8 @@ static void applet_change_pixel_size(GtkWidget *w, int size, gpointer data)
 	if (!ad->skin) return; /* we are done if in startup */
 
 	reload_theme(ad);
+	return;
+        w = NULL;
 }
 #endif
 
@@ -411,7 +426,9 @@ static gint applet_save_session(GtkWidget *widget, gchar *privcfgpath,
 {
 	AppData *ad = data;
         property_save(privcfgpath, ad);
-        return FALSE;
+	return FALSE;
+	widget = NULL;
+	globcfgpath = NULL;
 }
 
 static GtkWidget * applet_start_new_applet(const gchar *goad_id,
@@ -429,6 +446,8 @@ static GtkWidget * applet_start_new_applet(const gchar *goad_id,
 	create_new_app(applet);
 
 	return applet;
+	params = NULL;
+	nparams = 0;
 }
 
 int main (int argc, char *argv[])
